@@ -2,7 +2,7 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import Optional
 
-from dataclasses_json import dataclass_json
+from dataclasses_json import dataclass_json, Undefined
 
 from telescope_sdk.utils import convert_country_name_to_iso_code
 
@@ -14,7 +14,7 @@ class Source(Enum):
     UNKNOWN = "UNKNOWN"
 
 
-@dataclass_json
+@dataclass_json(undefined=Undefined.EXCLUDE)
 @dataclass
 class TelescopeBaseType:
     """
